==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-sysstat/translations/sysstat_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>Colors de las estatisticas sistèma</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>Grafic</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>&amp;Grasilha</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>Cambiar...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>Tít&amp;ol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>&amp;Prioritat</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>A&amp;utre</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>&amp;Frequéncia</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>S&amp;istèma</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>&amp;Utilizaire</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>Escam&amp;bi</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplicacions</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>&amp;Tampons</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>Ret</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>&amp;Recebut</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>&amp;Enviat</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation type="unfinished">Grafic</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation type="unfinished">CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation type="unfinished">Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation type="unfinished">Ret</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="400"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="449"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="491"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="525"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="555"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>min : %1%&lt;br&gt;max : %2%</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.4-1.src.tar.gz: lxqt-panel-2.1.4/plugin-sysstat/translations/sysstat_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>Colors de las estatisticas sistèma</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>Grafic</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>&amp;Grasilha</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>Cambiar...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>Tít&amp;ol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>&amp;Prioritat</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>A&amp;utre</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>&amp;Frequéncia</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>S&amp;istèma</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>&amp;Utilizaire</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>Escam&amp;bi</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplicacions</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>&amp;Tampons</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>Ret</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>&amp;Recebut</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>&amp;Enviat</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation>Grafic</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation>&amp;Títol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation>&amp;Font</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation>T&amp;ipe</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colors</source>
        <translation>Colors</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation>Color personalizat...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation>Ret</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation type="unfinished">CPU0</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation type="unfinished">CPU1</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation type="unfinished">CPU2</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation type="unfinished">CPU3</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation type="unfinished">CPU4</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation type="unfinished">CPU5</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation type="unfinished">CPU6</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation type="unfinished">CPU7</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation type="unfinished">CPU8</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation type="unfinished">CPU9</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation type="unfinished">CPU10</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation>CPU11</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation>CPU12</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation>CPU13</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation>CPU14</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation>CPU15</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation>CPU16</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation>CPU17</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation>CPU18</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation>CPU19</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation>CPU20</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation>CPU21</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation>CPU22</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation>CPU23</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation>memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation>memòria d’escambi</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="407"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="456"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="498"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="532"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="562"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>min : %1%&lt;br&gt;max : %2%</translation>
    </message>
</context>
</TS>
